Enum FlagUpdateError
Source pub enum FlagUpdateError {
PageNotMapped,
ParentEntryHugePage,
}
An error indicating that an update_flags call failed.
The given page is not mapped to a physical frame.
An upper level page table entry has the HUGE_PAGE flag set, which means that the
given page is part of a huge page and can’t be freed individually.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.