This type represents a page whose mapping has changed in the page table.
The old mapping might be still cached in the translation lookaside buffer (TLB), so it needs
to be flushed from the TLB before it’s accessed. This type is returned from a function that
changed the mapping of a page to ensure that the TLB flush is not forgotten.